@@ -11,7 +11,7 @@
 # Author   : Kenneth J. Pronovici <pronovic@ieee.org>
 # Language : Python (>= 2.3)
 # Project  : Cedar Backup, release 2
-# Revision : $Id: release.py 933 2008-12-09 02:07:06Z pronovic $
+# Revision : $Id: release.py 973 2010-05-22 17:00:56Z pronovic $
 # Purpose  : Provides location to maintain release information.
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
@@ -33,8 +33,8 @@ Provides location to maintain version information.
 
 AUTHOR      = "Kenneth J. Pronovici"
 EMAIL       = "pronovic@ieee.org"
-COPYRIGHT   = "2004-2008"
-VERSION     = "2.19.2"
-DATE        = "08 Dec 2008"
+COPYRIGHT   = "2004-2010"
+VERSION     = "2.19.6"
+DATE        = "22 May 2010"
 URL         = "http://cedar-backup.sourceforge.net/"
 
